(TeX-add-style-hook
 "refs"
 (lambda ()
   (LaTeX-add-bibitems
    "monnahan2018"
    "monnahan2019"
    "betancourt2014"
    "kristensen2016"
    "fournier2012"
    "monnahan2017"
    "carpenter2017"
    "hoffman2014"
    "neal2011"
    "betancourt2016"
    "betancourt2017intro"
    "stan2017"))
 :bibtex)

